{ config, pkgs, ... }:
{
  imports = [
    ./base-minimal.nix

    # Filesystem settings.
    ./btrfsScrub.nix

    # DNS settings.
    #
    # TODO add nix option
    ./dns.nix # Encrypted DNS queries to custom name servers.
    #./dns-unencrypted.nix # Custom name servers.

    # Shell settings.
    ./bash.nix # bash settings.
    ./zsh.nix # zsh as default shell for yoda and root.
    ./fzf.nix # Fuzzy command history and file search.

    # nixpkgs config
    ./home-manager.nix

    # Nix garbage collection.
    ./nix-gc.nix
    # Display contact information during boot.
    ./initrd-contact-info.nix
  ];

  # Enables wireless support via wpa_supplicant.
  # networking.wireless.enable = true;
  #
  # Enable networking.
  networking.networkmanager.enable = true;
  #
  users.users."yoda" = {
    extraGroups = [ "networkmanager" ];
  };

  # Optimise nix store during every build. This may slow down builds.
  # https://nixos.wiki/wiki/Storage_optimization
  nix.settings.auto-optimise-store = true;

  # Firewall.
  # https://nixos.wiki/wiki/Firewall
  # Note: Firewall rules may be bypassed/overwritten by Docker, as per https://github.com/NixOS/nixpkgs/issues/111852
  networking.firewall.enable = true;
}
